@@ -21,15 +21,13 @@
 #ifndef CONFIGDIALOG_H
 #define CONFIGDIALOG_H
 
-#include <kcmodule.h>
+#include <KCModule>
 
 #include "data.h"
 #include "ui_configdlg.h"
 
-class QStandardItem;
-class QStandardItemModel;
-class QTimer;
 class QTreeWidgetItem;
+class KCalendarSystem;
 
 /**
  * This is the configuration dialog for KNemo
@@ -65,6 +63,7 @@ private slots:
     void buttonDeleteSelected();
     void buttonAddCommandSelected();
     void buttonRemoveCommandSelected();
+    void setUpDownButtons( QTreeWidgetItem* item );
     void buttonCommandUpSelected();
     void buttonCommandDownSelected();
     void buttonAddToolTipSelected();
@@ -72,58 +71,45 @@ private slots:
     void buttonNotificationsSelected();
     void interfaceSelected( int row );
     void aliasChanged( const QString& text );
-    void iconSetChanged( int set );
-    void backendChanged( int set );
-    void checkBoxNotConnectedToggled( bool on );
-    void checkBoxNotExistingToggled( bool on );
+    void iconThemeChanged( int set );
+    void comboHidingChanged( int val );
     void checkBoxStatisticsToggled( bool on );
+    void checkBoxCustomBillingToggled( bool on );
+    void warnThresholdChanged( double val );
+    void warnRxTxToggled( bool on );
+    void billingStartInputChanged( const QDate& );
+    void billingMonthsInputChanged( int value );
     void checkBoxStartKNemoToggled( bool on );
-    void spinBoxTrafficValueChanged( int value );
-    void checkBoxCustomToggled( bool on );
+    void colorButtonChanged();
+    void advancedButtonClicked();
     void listViewCommandsSelectionChanged( QTreeWidgetItem *current, QTreeWidgetItem *previous );
     void listViewCommandsChanged( QTreeWidgetItem* item, int column );
-
-    /**
-     * These three are generic.
-     * They are used for all plotter settings to activate the
-     * 'Apply' button when something was changed by the user.
-     */
-    void checkBoxToggled( bool );
-    void spinBoxValueChanged( int );
-    void kColorButtonChanged( const QColor& );
+    void moveTips( QListWidget *from, QListWidget *to );
 
 private:
+    void setMaxDay();
     void setupToolTipTab();
-    void setupToolTipArray();
-    void updateStatisticsEntries( void );
-
-    enum IconSet
-    {
-        MONITOR = 0,
-        MODEM,
-        NETWORK,
-        WIRELESS
-    };
+    void setupToolTipMap();
+    void updateControls( InterfaceSettings *settings );
+    InterfaceSettings * getItemSettings();
+    int findIndexFromName( const QString& internalName );
+    QString findNameFromIndex( int index );
+    QPixmap textIcon( QString incomingText, QString outgoingText, int status );
+    QPixmap barIcon( int status );
 
     int mToolTipContent;
     bool mLock;
     Ui::ConfigDlg* mDlg;
-    QColor mColorVLines;
-    QColor mColorHLines;
-    QColor mColorIncoming;
-    QColor mColorOutgoing;
-    QColor mColorBackground;
+    const KCalendarSystem* mCalendar;
+    int mMaxDay;
+
+    // Delete this once KCalendarSystem fixed
+    QString mDefaultCalendarType;
+
     KSharedConfigPtr mConfig;
     QMap<QString, InterfaceSettings *> mSettingsMap;
     QMap<quint32, QString> mToolTips;
     QList<QString> mDeletedIfaces;
-    QStringList mIconSets;
-
-    static const QString ICON_DISCONNECTED;
-    static const QString ICON_CONNECTED;
-    static const QString ICON_INCOMING;
-    static const QString ICON_OUTGOING;
-    static const QString ICON_TRAFFIC;
 };
 
 #endif // CONFIGDIALOG_H
