@@ -24,7 +24,7 @@
 #include <KDialog>
 #include <KSharedConfig>
 
-#include "global.h"
+#include "plotterconfigdialog.h"
 
 class FancyPlotterLabel;
 class KSignalPlotter;
@@ -34,14 +34,9 @@ class InterfacePlotterDialog : public KDialog
 {
 Q_OBJECT
 public:
-    InterfacePlotterDialog( const PlotterSettings &, QString );
+    InterfacePlotterDialog( QString );
     virtual ~InterfacePlotterDialog();
 
-    /**
-     * Configure the signal plotter with user settings
-     */
-    void configChanged();
-
     /**
      * Update the signal plotter with new data
      */
@@ -50,25 +45,23 @@ public:
 protected:
     bool event( QEvent *e );
 
+private slots:
+    void configFinished();
+    void saveConfig();
 
 private:
-    enum VisibleBeams
-    {
-        NONE = 0,
-        INCOMING_TRAFFIC = 1,
-        OUTGOING_TRAFFIC = 2,
-        BOTH = 3
-    };
+    void showContextMenu( const QPoint& );
+    void loadConfig();
+    void configChanged();
+    void configPlotter();
 
     KSharedConfigPtr mConfig;
+    PlotterConfigDialog *mConfigDlg;
     bool mSetPos;
     bool mWasShown;
-    const PlotterSettings& mPlotterSettings;
+    PlotterSettings mSettings;
     QString mName;
-    int mOutgoingPos;
-    int mIncomingPos;
     KSignalPlotter *mPlotter;
-    VisibleBeams mVisibleBeams;
     FancyPlotterLabel *mReceivedLabel;
     FancyPlotterLabel *mSentLabel;
     QBoxLayout *mLabelLayout;
