@@ -109,12 +109,8 @@ private:
     QTimer* mPollTimer;
     // application wide settings are stored here
     GeneralData mGeneralData;
-    // settings for the traffic plotter are stored here
-    PlotterSettings mPlotterSettings;
     // the name of backend we currently use
     QString mBackendName;
-    // the backend used to update the interface informations
-    BackendBase* mBackend;
     // a list of all interfaces the user wants to monitor
     QHash<QString, Interface *> mInterfaceHash;
 
