@@ -26,7 +26,7 @@
 #include <QtGui/QPixmap>
 #include <QtGui/QPainterPath>
 
-#include <kdebug.h>
+//#include <kdebug.h>
 #include <kglobal.h>
 #include <klocale.h>
 #include <kapplication.h>
@@ -84,6 +84,8 @@ KSignalPlotter::KSignalPlotter( QWidget *parent)
   mFillOpacity = 20;
   mRescaleTime = 0;
   mUnit = "KiB/s";
+
+  mVisibleBeams = NONE;
 }
 
 KSignalPlotter::~KSignalPlotter()
@@ -97,6 +99,10 @@ void KSignalPlotter::setUnit(const QString &unit) {
   mUnit= unit;
 }
 
+void KSignalPlotter::setVisibleBeams( int beams )
+{
+    mVisibleBeams = beams;
+}
 
 void KSignalPlotter::addBeam( const QColor &color )
 {
@@ -116,7 +122,7 @@ QColor KSignalPlotter::beamColor( int index ) {
 
 void KSignalPlotter::setBeamColor( int index, QColor color ) {
   if(!color.isValid()) {
-	  kDebug(1215) << "Invalid color";
+	  //kDebug(1215) << "Invalid color";
 	  return;
   }
 
@@ -168,7 +174,7 @@ void KSignalPlotter::addSample( const QList<double>& sampleBuf )
       return;
   }
   if(sampleBuf.count() != mBeamColors.count()) {
-	  kDebug(1215) << "Sample data discarded - contains wrong number of beams";
+	  //kDebug(1215) << "Sample data discarded - contains wrong number of beams";
 	  return;
   }
   mBeamData.prepend(sampleBuf);
@@ -208,7 +214,7 @@ void KSignalPlotter::reorderBeams( const QList<int>& newOrder )
   QList< QList<double> >::Iterator it;
   for(it = mBeamData.begin(); it != mBeamData.end(); ++it) {
     if(newOrder.count() != (*it).count()) {
-      kDebug(1215) << "Serious problem in move sample.  beamdata[i] has " << (*it).count() << " and neworder has " << newOrder.count();
+      //kDebug(1215) << "Serious problem in move sample.  beamdata[i] has " << (*it).count() << " and neworder has " << newOrder.count();
     } else {
      QList<double> newBeam;
      for(int i = 0; i < newOrder.count(); i++) {
@@ -334,7 +340,7 @@ void KSignalPlotter::setVerticalLinesColor( const QColor &color )
 {
   if(mVerticalLinesColor == color) return;
   if(!color.isValid()) {
-	  kDebug(1215) << "Invalid color";
+	  //kDebug(1215) << "Invalid color";
 	  return;
   }
 
@@ -402,7 +408,7 @@ bool KSignalPlotter::showHorizontalLines() const
 void KSignalPlotter::setAxisFontColor( const QColor &color )
 {
   if(!color.isValid()) {
-	  kDebug(1215) << "Invalid color";
+	  //kDebug(1215) << "Invalid color";
 	  return;
   }
 
@@ -418,7 +424,7 @@ QColor KSignalPlotter::axisFontColor() const
 void KSignalPlotter::setHorizontalLinesColor( const QColor &color )
 {
   if(!color.isValid()) {
-	  kDebug(1215) << "Invalid color";
+	  //kDebug(1215) << "Invalid color";
 	  return;
   }
 
@@ -487,7 +493,7 @@ void KSignalPlotter::setBackgroundColor( const QColor &color )
 {
   if(color == mBackgroundColor) return;
   if(!color.isValid()) {
-	  kDebug(1215) << "Invalid color";
+	  //kDebug(1215) << "Invalid color";
 	  return;
   }
   mBackgroundColor = color;
@@ -550,6 +556,15 @@ void KSignalPlotter::paintEvent( QPaintEvent* event)
     drawWidget(&p, QRect(0,0,w, h), false);
 }
 
+void KSignalPlotter::hideEvent( QHideEvent* )
+{
+#ifdef USE_QIMAGE
+  mScrollableImage = QImage();
+#else
+  mScrollableImage = QPixmap();
+#endif
+}
+
 void KSignalPlotter::drawWidget(QPainter *p, QRect boundingBox, bool onlyDrawPlotter)
 {
   if(boundingBox.height() <= 2 || boundingBox.width() <= 2 ) return;
@@ -823,6 +838,13 @@ void KSignalPlotter::drawBeam(QPainter *p, const QRect &boundingBox, int horizon
   float y1 = 0;
   float y2 = 0;
   for (int j =  qMin(datapoints.size(), mBeamColors.size())-1; j >=0 ; --j) {
+    if ( (j == INCOMING_BEAM && ! (mVisibleBeams & INCOMING_TRAFFIC) ) ||
+         (j == OUTGOING_BEAM && ! (mVisibleBeams & OUTGOING_TRAFFIC) )
+       )
+    {
+        continue;
+    }
+
     if(!mStackBeams)
       y0 = y1 = y2 = 0;
     y0 += boundingBox.bottom() - (datapoints[j] - mNiceMinValue)*scaleFac;
@@ -851,9 +873,12 @@ void KSignalPlotter::drawBeam(QPainter *p, const QRect &boundingBox, int horizon
         path.lineTo(x0,boundingBox.bottom());
         path.lineTo(x1,boundingBox.bottom());
         path.lineTo(x1,y1);
-	QColor fillColor = mBeamColors[j];
-	fillColor.setAlpha(mFillOpacity);
-        p->fillPath(path, fillColor);
+        QColor fillColor = mBeamColors[j];
+        fillColor.setAlpha(mFillOpacity);
+        QBrush brush = QBrush(fillColor);
+        p->setBrush(brush);
+        p->setPen(Qt::NoPen);
+        p->drawPath(path);
     }
   }
 }
